@@ -7,7 +7,7 @@ fi
 
 #SVN_LOC=http://uv-desktop/svn/home/external/mosquitto
 SVN_LOC=http://192.168.15.50/svn/home/external/mosquitto
-MQVER=0.11.2
+MQVER=0.15
 SVNVER=`svn log $SVN_LOC --limit=1 | grep '^r' | sed 's/^r\([0-9]*\).*/\1/'`
 
 rm build-stamp configure-stamp
@@ -21,8 +21,9 @@ echo y | dh_make --createorig --single -e yuvraaj@gmail.com -c lgpl
 # First create everything for libmosquittopp
 cp build-files/libmosquittopp.control debian/control
 cp build-files/libmosquittopp.rules debian/rules
-cp build-files/libmosquittopp.install debian/
+#cp build-files/libmosquittopp.install debian/
 
+# Fix the changelog to use the changelog we created.
 head -1 ./debian/changelog >dest.txt ; cat ./build-files/changelog >>dest.txt ; tail -2 ./debian/changelog | head -1 | sed 's/unknown/Yuvraaj Kelkar/g' >>dest.txt
 mv dest.txt ./debian/changelog
 
